@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import pytest
 
 from tox_ini_fmt.formatter.requires import requires
 
 
 @pytest.mark.parametrize(
-    "value, result",
+    ("value", "result"),
     [
         ("", []),
         ("\t", []),
